function [ Msd ] = MeanSquaredDisplacement( Trajectory, TauValues )
%MeanSquaredDisplacement computes the MSD of a particle trajectory for the
%specified time intervale
%   Trajectory is a MxN matrix, where M is the length of the trajectory and
%   N is the number of dimensions.
%   TauValues is a vector of intervals over which the MSD will be computed,
%   specified in number of samples. TauValues may contain integers greater 
%   than zero and less than the length of Trajectory

    trajectoryLength = size( Trajectory, 1 );
    Msd = zeros( 1, length( TauValues ) );
    
    for ii = 1:length( TauValues )
        interval = TauValues(ii);
        startIndex = 1:(trajectoryLength - interval);
        endIndex = startIndex + interval;
        
        Msd(ii) = mean( sum( (Trajectory( endIndex, : ) - Trajectory(  startIndex, : ) ).^2, 2 ) );
    end
end